# coding: utf-8

from drescher.utils import to_date, to_uuid


class InputFile(object):
    __slots__ = (
        'unit',
        'id', 'name', 'checksum',
        'size', 'type',
        'parameters', 'received_at'
    )

    _RESERVED = frozenset(('unit', ))
    _TRANSLATE = {
        'type': 'tipe'
    }
    _CAST = {
        'id': to_uuid,
        'received_at': to_date,
    }

    DATA_FILE = 1
    HELPER_FILE = 2

    def __init__(self, unit, input_file_data):
        """
        :type unit: Unit
        :type input_file_data: dict
        """
        
        self.unit = unit

        for name in self.__slots__:
            if name not in self._RESERVED:
                translated = self._TRANSLATE.get(name, name)
                value = input_file_data[translated]

                if translated in self._CAST:
                    value = self._CAST[translated](value)

                setattr(self, name, value)


class Unit(object):
    __slots__ = (
        'id', 'year', 'production_id', 
        'status', 'is_test', 'notes',
        'input_files',
        'created_at', 'created_by'
    )

    _RESERVED = frozenset(('files', ))
    _TRANSLATE = {
        'input_files': 'files'
    }
    _CAST = {
        'created_at': to_date
    }

    DATA_RECEIVING = 1
    STARTED = 2
    IN_PROGRESS = 20
    CLOSED = 30

    def __init__(self, unit_data):
        """
        :type unit_data: dict
        """

        for name in self.__slots__:
            if name not in self._RESERVED:
                translated = self._TRANSLATE.get(name, name)
                value = unit_data[translated]

                if translated in self._CAST:
                    value = self._CAST[translated](value)

                setattr(self, name, value)
                
        self.input_files = tuple(InputFile(self, _) for _ in unit_data['files'])




# coding: utf-8

from datetime import datetime
from uuid import UUID


def to_date(date_string, format='%Y-%m-%d %H:%M:%S'):
    return datetime.strptime(date_string, format)


def to_uuid(hex):
    return UUID(hex)



# coding: utf-8

from __future__ import print_function
from copy import deepcopy

import requests
from six.moves.urllib.parse import urljoin

from drescher import endpoints
from drescher.models import Unit

__version__ = '1.0.1'


DRESCHER_API = 'https://upload.drescher.hu/api/'


class Drescher(object):
    def __init__(self, username, api_key, api=DRESCHER_API):
        """
        :type username: str
        :type api_key: str
        :type api: str
        """
        
        self._auth = {
            'username': username,
            'api_key': api_key
        }
        self._api = api

    def _post(self, endpoint, json=None, **kwargs):
        """
        :type endpoint: str
        :type json: dict
        :type kwargs: dict
        :param kwargs: Any keyword argument that can be passed to `requests.post()`
        :rtype: dict
        """

        url = urljoin(self._api, endpoint.lstrip('/'))

        if json is None:
            json = {}
        else:
            json = deepcopy(json)
        json.update(self._auth)

        reply = requests.post(url, json=json, **kwargs)
        reply.raise_for_status()

        return reply.json()

    def _get(self, endpoint, params=None, **kwargs):
        """
        :type endpoint: str
        :type params: dict
        :type kwargs: dict
        :param kwargs: Any keyword argument that can be passed to `requests.get()`
        :rtype: dict
        """

        url = urljoin(self._api, endpoint.lstrip('/'))

        if params is None:
            params = {}
        else:
            params = deepcopy(params)
        params.update(self._auth)

        reply = requests.get(url, params=params, **kwargs)
        reply.raise_for_status()

        return reply.json()

    def get_unit_list(self):
        """
        :return: Unit
        """
        for unit in self._get(endpoints.UNIT_LIST):
            yield Unit(unit)



# coding: utf-8

from setuptools import setup

from drescher import __version__

setup(
    name='drescher-client',
    version=__version__,
    description='The public Drescher API client',
    packages=['drescher'],
    install_requires=[
        'requests>=2.11.0',
        'six>=1.10.0'
    ]
)
